AccountData

Struct AccountData 

pub struct AccountData {
    pub sequence_number: String,
    pub authentication_key: String,
}
AccountData : Account data A simplified version of the onchain Account resource

Fields

sequence_number: String

A string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.

authentication_key: String

All bytes (Vec) data is represented as hex-encoded string prefixed with 0x and fulfilled with two hex digits per byte. Unlike the Address type, HexEncodedBytes will not trim any zeros.

Implementations

Source

impl AccountData

pub fn new(sequence_number: String, authentication_key: String) -> AccountData

Account data A simplified version of the onchain Account resource