pub struct AptosError {
pub message: String,
pub error_code: AptosErrorCode,
pub vm_error_code: Option<i32>,
}Expand description
AptosError : This is the generic struct we use for all API errors, it contains a string message and an Aptos API specific error code.
Fields
message: StringA message describing the error
error_code: AptosErrorCodevm_error_code: Option<i32>A code providing VM error details when submitting transactions to the VM
Implementations
Sourceimpl AptosError
impl AptosError
Sourcepub fn new(message: String, error_code: AptosErrorCode) -> AptosError
pub fn new(message: String, error_code: AptosErrorCode) -> AptosError
This is the generic struct we use for all API errors, it contains a string message and an Aptos API specific error code.