Module aptos_error_code

Module aptos_error_code 

Enums

AptosErrorCode
AptosErrorCode : These codes provide more granular error information beyond just the HTTP status code of the response. These codes provide more granular error information beyond just the HTTP status code of the response.