pub enum AptosErrorCode {
Show 21 variants
AccountNotFound,
ResourceNotFound,
ModuleNotFound,
StructFieldNotFound,
VersionNotFound,
TransactionNotFound,
TableItemNotFound,
BlockNotFound,
StateValueNotFound,
VersionPruned,
BlockPruned,
InvalidInput,
InvalidTransactionUpdate,
SequenceNumberTooOld,
VmError,
HealthCheckFailed,
MempoolIsFull,
InternalError,
WebFrameworkError,
BcsNotSupported,
ApiDisabled,
}Expand description
AptosErrorCode : These codes provide more granular error information beyond just the HTTP status code of the response. These codes provide more granular error information beyond just the HTTP status code of the response.
Variants
AccountNotFound
ResourceNotFound
ModuleNotFound
StructFieldNotFound
VersionNotFound
TransactionNotFound
TableItemNotFound
BlockNotFound
StateValueNotFound
VersionPruned
BlockPruned
InvalidInput
InvalidTransactionUpdate
SequenceNumberTooOld
VmError
HealthCheckFailed
MempoolIsFull
InternalError
WebFrameworkError
BcsNotSupported
ApiDisabled