pub struct Block {
pub block_height: String,
pub block_hash: String,
pub block_timestamp: String,
pub first_version: String,
pub last_version: String,
pub transactions: Option<Vec<Transaction>>,
}Expand description
Block : A Block with or without transactions This contains the information about a transactions along with associated transactions if requested
Fields
block_height: StringA string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.
block_hash: Stringblock_timestamp: StringA string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.
first_version: StringA string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.
last_version: StringA string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.
transactions: Option<Vec<Transaction>>The transactions in the block in sequential order