BlockMetadataTransaction

Struct BlockMetadataTransaction 

pub struct BlockMetadataTransaction {
Show 19 fields pub version: String, pub hash: String, pub state_change_hash: String, pub event_root_hash: String, pub state_checkpoint_hash: Option<String>, pub gas_used: String, pub success: bool, pub vm_status: String, pub accumulator_root_hash: String, pub changes: Vec<WriteSetChange>, pub id: String, pub epoch: String, pub round: String, pub events: Vec<Event>, pub previous_block_votes_bitvec: Vec<i32>, pub proposer: String, pub failed_proposer_indices: Vec<i32>, pub timestamp: String, pub block_metadata_extension: Option<Box<BlockMetadataTransactionBlockMetadataExtension>>,
}
BlockMetadataTransaction : A block metadata transaction This signifies the beginning of a block, and contains information about the specific block

Fields

version: String

A string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.

hash: Stringstate_change_hash: Stringevent_root_hash: Stringstate_checkpoint_hash: Option<String>gas_used: String

A string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.

success: bool

Whether the transaction was successful

vm_status: String

The VM status of the transaction, can tell useful information in a failure

accumulator_root_hash: Stringchanges: Vec<WriteSetChange>

Final state of resources changed by the transaction

id: Stringepoch: String

A string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.

round: String

A string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.

events: Vec<Event>

The events emitted at the block creation

previous_block_votes_bitvec: Vec<i32>

Previous block votes

proposer: String

A hex encoded 32 byte Aptos account address. This is represented in a string as a 64 character hex string, sometimes shortened by stripping leading 0s, and adding a 0x. For example, address 0x0000000000000000000000000000000000000000000000000000000000000001 is represented as 0x1.

failed_proposer_indices: Vec<i32>

The indices of the proposers who failed to propose

timestamp: String

A string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.

block_metadata_extension: Option<Box<BlockMetadataTransactionBlockMetadataExtension>>

Implementations

Source

impl BlockMetadataTransaction

pub fn new( version: String, hash: String, state_change_hash: String, event_root_hash: String, gas_used: String, success: bool, vm_status: String, accumulator_root_hash: String, changes: Vec<WriteSetChange>, id: String, epoch: String, round: String, events: Vec<Event>, previous_block_votes_bitvec: Vec<i32>, proposer: String, failed_proposer_indices: Vec<i32>, timestamp: String, ) -> BlockMetadataTransaction

A block metadata transaction This signifies the beginning of a block, and contains information about the specific block