pub struct DeleteModule {
pub address: String,
pub state_key_hash: String,
pub module: String,
}Expand description
DeleteModule : Delete a module
Fields
address: StringA hex encoded 32 byte Aptos account address. This is represented in a string as a 64 character hex string, sometimes shortened by stripping leading 0s, and adding a 0x. For example, address 0x0000000000000000000000000000000000000000000000000000000000000001 is represented as 0x1.
state_key_hash: StringState key hash
module: StringMove module id is a string representation of Move module. Format: {address}::{module name} address should be hex-encoded 32 byte account address that is prefixed with 0x. Module name is case-sensitive.
Implementations
Sourceimpl DeleteModule
impl DeleteModule