pub struct MoveFunction {
pub name: String,
pub visibility: MoveFunctionVisibility,
pub is_entry: bool,
pub is_view: bool,
pub generic_type_params: Vec<MoveFunctionGenericTypeParam>,
pub params: Vec<String>,
pub return: Vec<String>,
}Expand description
MoveFunction : Move function
Fields
name: Stringvisibility: MoveFunctionVisibilityis_entry: boolWhether the function can be called as an entry function directly in a transaction
is_view: boolWhether the function is a view function or not
generic_type_params: Vec<MoveFunctionGenericTypeParam>Generic type params associated with the Move function
params: Vec<String>Parameters associated with the move function
return: Vec<String>Return type of the function
Implementations
Sourceimpl MoveFunction
impl MoveFunction
Sourcepub fn new(
name: String,
visibility: MoveFunctionVisibility,
is_entry: bool,
is_view: bool,
generic_type_params: Vec<MoveFunctionGenericTypeParam>,
params: Vec<String>,
return: Vec<String>,
) -> MoveFunction
pub fn new( name: String, visibility: MoveFunctionVisibility, is_entry: bool, is_view: bool, generic_type_params: Vec<MoveFunctionGenericTypeParam>, params: Vec<String>, return: Vec<String>, ) -> MoveFunction
Move function