pub struct ScriptPayload {
pub code: Box<MoveScriptBytecode>,
pub type_arguments: Vec<String>,
pub arguments: Vec<Value>,
}Expand description
ScriptPayload : Payload which runs a script that can run multiple functions
Fields
code: Box<MoveScriptBytecode>type_arguments: Vec<String>Type arguments of the function
arguments: Vec<Value>Arguments of the function
Implementations
Sourceimpl ScriptPayload
impl ScriptPayload
Sourcepub fn new(
code: MoveScriptBytecode,
type_arguments: Vec<String>,
arguments: Vec<Value>,
) -> ScriptPayload
pub fn new( code: MoveScriptBytecode, type_arguments: Vec<String>, arguments: Vec<Value>, ) -> ScriptPayload
Payload which runs a script that can run multiple functions