pub struct ScriptWriteSet {
pub execute_as: String,
pub script: Box<ScriptPayload>,
}Fields
execute_as: StringA hex encoded 32 byte Aptos account address. This is represented in a string as a 64 character hex string, sometimes shortened by stripping leading 0s, and adding a 0x. For example, address 0x0000000000000000000000000000000000000000000000000000000000000001 is represented as 0x1.
script: Box<ScriptPayload>Implementations
Sourceimpl ScriptWriteSet
impl ScriptWriteSet
pub fn new(execute_as: String, script: ScriptPayload) -> ScriptWriteSet