pub struct StateCheckpointTransaction {
pub version: String,
pub hash: String,
pub state_change_hash: String,
pub event_root_hash: String,
pub state_checkpoint_hash: Option<String>,
pub gas_used: String,
pub success: bool,
pub vm_status: String,
pub accumulator_root_hash: String,
pub changes: Vec<WriteSetChange>,
pub timestamp: String,
}Expand description
StateCheckpointTransaction : A state checkpoint transaction
Fields
version: StringA string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.
hash: Stringstate_change_hash: Stringevent_root_hash: Stringstate_checkpoint_hash: Option<String>gas_used: StringA string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.
success: boolWhether the transaction was successful
vm_status: StringThe VM status of the transaction, can tell useful information in a failure
accumulator_root_hash: Stringchanges: Vec<WriteSetChange>Final state of resources changed by the transaction
timestamp: StringA string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.
Implementations