UserTransaction

Struct UserTransaction 

pub struct UserTransaction {
Show 19 fields pub version: String, pub hash: String, pub state_change_hash: String, pub event_root_hash: String, pub state_checkpoint_hash: Option<String>, pub gas_used: String, pub success: bool, pub vm_status: String, pub accumulator_root_hash: String, pub changes: Vec<WriteSetChange>, pub sender: String, pub sequence_number: String, pub max_gas_amount: String, pub gas_unit_price: String, pub expiration_timestamp_secs: String, pub payload: Box<TransactionPayload>, pub signature: Option<Box<TransactionSignature>>, pub events: Vec<Event>, pub timestamp: String,
}
UserTransaction : A transaction submitted by a user to change the state of the blockchain

Fields

version: String

A string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.

hash: Stringstate_change_hash: Stringevent_root_hash: Stringstate_checkpoint_hash: Option<String>gas_used: String

A string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.

success: bool

Whether the transaction was successful

vm_status: String

The VM status of the transaction, can tell useful information in a failure

accumulator_root_hash: Stringchanges: Vec<WriteSetChange>

Final state of resources changed by the transaction

sender: String

A hex encoded 32 byte Aptos account address. This is represented in a string as a 64 character hex string, sometimes shortened by stripping leading 0s, and adding a 0x. For example, address 0x0000000000000000000000000000000000000000000000000000000000000001 is represented as 0x1.

sequence_number: String

A string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.

max_gas_amount: String

A string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.

gas_unit_price: String

A string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.

expiration_timestamp_secs: String

A string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.

payload: Box<TransactionPayload>signature: Option<Box<TransactionSignature>>events: Vec<Event>

Events generated by the transaction

timestamp: String

A string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.

Implementations

Source

impl UserTransaction

pub fn new( version: String, hash: String, state_change_hash: String, event_root_hash: String, gas_used: String, success: bool, vm_status: String, accumulator_root_hash: String, changes: Vec<WriteSetChange>, sender: String, sequence_number: String, max_gas_amount: String, gas_unit_price: String, expiration_timestamp_secs: String, payload: TransactionPayload, events: Vec<Event>, timestamp: String, ) -> UserTransaction

A transaction submitted by a user to change the state of the blockchain