pub struct WriteModule {
pub address: String,
pub state_key_hash: String,
pub data: Box<MoveModuleBytecode>,
}Expand description
WriteModule : Write a new module or update an existing one
Fields
address: StringA hex encoded 32 byte Aptos account address. This is represented in a string as a 64 character hex string, sometimes shortened by stripping leading 0s, and adding a 0x. For example, address 0x0000000000000000000000000000000000000000000000000000000000000001 is represented as 0x1.
state_key_hash: StringState key hash
data: Box<MoveModuleBytecode>Implementations
Sourceimpl WriteModule
impl WriteModule
Sourcepub fn new(
address: String,
state_key_hash: String,
data: MoveModuleBytecode,
) -> WriteModule
pub fn new( address: String, state_key_hash: String, data: MoveModuleBytecode, ) -> WriteModule
Write a new module or update an existing one