pub struct WriteSetChangeWriteModule {
pub address: String,
pub state_key_hash: String,
pub data: Box<MoveModuleBytecode>,
pub type: Type,
}Fields
address: StringA hex encoded 32 byte Aptos account address. This is represented in a string as a 64 character hex string, sometimes shortened by stripping leading 0s, and adding a 0x. For example, address 0x0000000000000000000000000000000000000000000000000000000000000001 is represented as 0x1.
state_key_hash: StringState key hash
data: Box<MoveModuleBytecode>type: TypeImplementations
Sourceimpl WriteSetChangeWriteModule
impl WriteSetChangeWriteModule
pub fn new( address: String, state_key_hash: String, data: MoveModuleBytecode, type: Type, ) -> WriteSetChangeWriteModule