pub struct WriteSetChangeWriteTableItem {
pub state_key_hash: String,
pub handle: String,
pub key: String,
pub value: String,
pub data: Option<Box<DecodedTableData>>,
pub type: Type,
}Fields
state_key_hash: Stringhandle: StringAll bytes (Vec0x and fulfilled with two hex digits per byte. Unlike the Address type, HexEncodedBytes will not trim any zeros.
key: StringAll bytes (Vec0x and fulfilled with two hex digits per byte. Unlike the Address type, HexEncodedBytes will not trim any zeros.
value: StringAll bytes (Vec0x and fulfilled with two hex digits per byte. Unlike the Address type, HexEncodedBytes will not trim any zeros.
data: Option<Box<DecodedTableData>>type: TypeImplementations