pub struct AccountData {
pub sequence_number: String,
pub authentication_key: String,
}Expand description
AccountData : Account data A simplified version of the onchain Account resource
Fields
sequence_number: StringA string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.
authentication_key: StringAll bytes (Vec0x and fulfilled with two hex digits per byte. Unlike the Address type, HexEncodedBytes will not trim any zeros.
Implementations
Sourceimpl AccountData
impl AccountData
Sourcepub fn new(sequence_number: String, authentication_key: String) -> AccountData
pub fn new(sequence_number: String, authentication_key: String) -> AccountData
Account data A simplified version of the onchain Account resource