Module aptos_error_code
aptos_
client_
icp
0.0.1
Module aptos_
error_
code
Module Items
Enums
In aptos_
client_
icp::
models
aptos_client_icp
::
models
Module
aptos_
error_
code
Enums

Aptos
Error
Code
AptosErrorCode : These codes provide more granular error information beyond just the HTTP status code of the response. These codes provide more granular error information beyond just the HTTP status code of the response.