pub struct TransactionValidatorTransaction {Show 16 fields
pub validator_transaction_type: ValidatorTransactionType,
pub version: String,
pub hash: String,
pub state_change_hash: String,
pub event_root_hash: String,
pub state_checkpoint_hash: Option<String>,
pub gas_used: String,
pub success: bool,
pub vm_status: String,
pub accumulator_root_hash: String,
pub changes: Vec<WriteSetChange>,
pub events: Vec<Event>,
pub timestamp: String,
pub quorum_certified_update: Box<ExportedQuorumCertifiedUpdate>,
pub dkg_transcript: Box<ExportedDkgTranscript>,
pub type: Type,
}Fields
validator_transaction_type: ValidatorTransactionTypeversion: StringA string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.
hash: Stringstate_change_hash: Stringevent_root_hash: Stringstate_checkpoint_hash: Option<String>gas_used: StringA string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.
success: boolWhether the transaction was successful
vm_status: StringThe VM status of the transaction, can tell useful information in a failure
accumulator_root_hash: Stringchanges: Vec<WriteSetChange>Final state of resources changed by the transaction
events: Vec<Event>timestamp: StringA string containing a 64-bit unsigned integer. We represent u64 values as a string to ensure compatibility with languages such as JavaScript that do not parse u64s in JSON natively.
quorum_certified_update: Box<ExportedQuorumCertifiedUpdate>dkg_transcript: Box<ExportedDkgTranscript>type: TypeImplementations
Sourceimpl TransactionValidatorTransaction
impl TransactionValidatorTransaction
pub fn new( validator_transaction_type: ValidatorTransactionType, version: String, hash: String, state_change_hash: String, event_root_hash: String, gas_used: String, success: bool, vm_status: String, accumulator_root_hash: String, changes: Vec<WriteSetChange>, events: Vec<Event>, timestamp: String, quorum_certified_update: ExportedQuorumCertifiedUpdate, dkg_transcript: ExportedDkgTranscript, type: Type, ) -> TransactionValidatorTransaction